@@ -587,7 +587,7 @@ class Update(MethodsInterface):
         if pkg.info['DESCRIPTION']:
             name = _(pkg.info['DESCRIPTION'])
             name = name[:1].upper() + name[1:]
-        if not name:
+        if not name.strip():
             name = str(pkg)
 
         self.printSUCCESS(
